pub struct TempUploadFiles {
pub markdown: NamedTempFile,
pub cover: NamedTempFile,
}Expand description
Holds temporary files for upload, automatically cleaned up when dropped.
Fields
markdown: NamedTempFileTemp markdown file (in same dir as original for relative path resolution)
cover: NamedTempFileTemp cropped cover image (in system temp dir)